import type { ComputedRef, Ref } from 'vue';
import { nextTick, onActivated, onMounted, onUnmounted, ref, watch } from 'vue';
import type { ChatMessage } from '../model/types';
import emitter from '/@/utils/mitt';
import { debounce } from '/@/utils/util';

export type UseScrollOption = {
	chatListDom: Ref<HTMLDivElement>;
};

export const useScroll = (option: UseScrollOption) => {
	const { chatListDom } = option;
	const scrollStepToBottom = () => {
		const allStepList = document.querySelectorAll('.step-list');
		const lastStepList = allStepList[allStepList.length - 1];
		if (!lastStepList) return;
		lastStepList.scrollTop = lastStepList.scrollHeight - lastStepList.clientHeight;
	};
	const scrollToBottom = () => {
		nextTick(() => {
			if (chatListDom.value.scrollHeight > chatListDom.value.clientHeight) {
				chatListDom.value.scrollTop = chatListDom.value.scrollHeight - chatListDom.value.clientHeight;
				nextTick(() => {
					scrollStepToBottom();
				});
			}
		});
	};

	const scrollToTop = () => {
		nextTick(() => {
			chatListDom.value.scrollTop = 0;
		});
	};

	const checkIsBottom = () => {
		// 误差 2像素
		isBottom.value = Math.abs(chatListDom.value.scrollTop + chatListDom.value.clientHeight - chatListDom.value.scrollHeight) < 2;
	};
	const isBottom = ref(true);
	onMounted(() => {
		chatListDom.value.addEventListener('scrollend', checkIsBottom);
	});

	onUnmounted(() => {
		chatListDom.value?.removeEventListener('scrollend', checkIsBottom);
	});

	// emitter.on('amis.page.ready', debounceAmisScroll);

	// onUnmounted(() => {
	// 	emitter.off('amis.page.ready');
	// });

	onActivated(() => {
		scrollToBottom();
	});

	return {
		scrollToBottom,
		scrollToTop,
		isBottom,
	};
};
